@@ -59,9 +59,20 @@ class Gallery(Page, RichText):
                     image.verify()
                 except:
                     continue
-                path = default_storage.save(os.path.join(GALLERIES_UPLOAD_DIR,
-                          self.slug, name.decode("utf-8")), ContentFile(data))
-                self.images.add(GalleryImage(file=path))
+                path = os.path.join(GALLERIES_UPLOAD_DIR, self.slug,
+                                    name.decode("utf-8"))
+                try:
+                    saved_path = default_storage.save(path, ContentFile(data))
+                except UnicodeEncodeError:
+                    from warnings import warn
+                    warn("A file was saved that contains unicode "
+                         "characters in its path, but somehow the current "
+                         "locale does not support utf-8. You may need to set "
+                         "'LC_ALL' to a correct value, eg: 'en_US.UTF-8'.")
+                    path = os.path.join(GALLERIES_UPLOAD_DIR, self.slug,
+                                        unicode(name, errors="ignore"))
+                    saved_path = default_storage.save(path, ContentFile(data))
+                self.images.add(GalleryImage(file=saved_path))
             if delete_zip_import:
                 zip_file.close()
                 self.zip_import.delete(save=True)
