@@ -23,7 +23,7 @@ var toggleID = function(opened, id) {
     document.cookie = cookie + '=' + ids + '; path=/';
 };
 
-function showButtonWithChildren(){
+function showButtonWithChildren() {
 	$('li:has(li) .tree-toggle').css({visibility: 'visible'});
 	$('li:not(:has(li)) .tree-toggle').css({visibility: 'hidden'});
 }
@@ -36,6 +36,15 @@ $(function() {
         $('.delete').addClass('grappelli-delete');
     }
 
+    // There's a weird bug where the first click on a page name
+    // does nothing. If we remove the call to showButtonWithChildren
+    // it works fine, which doesn't make sense. So this click handler
+    // forces the anchors to go to their location.
+    $('#tree .changelink').click(function() {
+        location.href = $(this).attr('href');
+        return false;
+    });
+
     $('#tree .tree-toggle').click(function() {
         // Show/hide the branch and toggle the icon.
         var pageLink = $(this);
@@ -52,7 +61,7 @@ $(function() {
     if (ids) {
     	$('#page-' + ids.split(',').join(', #page-')).each(function(){
 			var pageLink = $(this);
-			pageLink.parent().parent().find('ul:first').toggle();			
+			pageLink.parent().parent().find('ul:first').toggle();
 			pageLink.find('.close').css('display', 'inline');
 			pageLink.find('.open').css('display', 'none');
 		});
